@@ -154,7 +154,8 @@ class Runner(object):
                               help='Force overwrite',
                               default=False)
             options, args = parser.parse_args(params)
-            self.setupindex(pypi, args[0], args[1], args[2:], overwrite=options.overwrite)
+            self.setupindex(pypi, args[0], args[1], args[2:],
+                            overwrite=options.overwrite)
         else:
             print "No such command: %s" % cmd
 
@@ -162,8 +163,11 @@ class Runner(object):
         if len(reqs) == 0:
             raise ValueError('Please specify one or more requirements')
 
-        if not overwrite and pypi.index_manager.has_index(distro_id, indexname):
-            raise ValueError('Index by the name of "%s" for distro "%s" already exists, use --overwrite to overwrite' % (indexname, distro_id))
+        if not overwrite and pypi.index_manager.has_index(distro_id,
+                                                          indexname):
+            raise ValueError('Index by the name of "%s" for distro "%s" '
+                             'already exists, use --overwrite to overwrite'
+                             % (indexname, distro_id))
 
         try:
             d = pkg_resources.get_distribution('virtualenv')
@@ -184,7 +188,8 @@ class Runner(object):
         pip_path = os.path.join(path, 'bin', 'pip')
         subprocess.call([pip_path, 'install'] + list(reqs))
 
-        froze = subprocess.Popen([pip_path, 'freeze'], stdout=subprocess.PIPE).communicate()[0]
+        froze = subprocess.Popen([pip_path, 'freeze'],
+                                 stdout=subprocess.PIPE).communicate()[0]
 
         print
         if overwrite and pypi.index_manager.has_index(distro_id, indexname):
@@ -194,9 +199,13 @@ class Runner(object):
         index_reqs = [x.strip() for x in froze.split('\n') if x.strip()]
         for x in index_reqs:
             req = pkg_resources.Requirement.parse(x)
-            pypi.index_manager.add_index_item(distro_id, indexname, req.project_name, req.specs[0][1])
+            pypi.index_manager.add_index_item(distro_id,
+                                              indexname,
+                                              req.project_name,
+                                              req.specs[0][1])
 
-        print 'Created index "%s" for distro "%s" with the following requirements' % (distro_id, indexname)
+        print 'Created index "%s" for distro "%s" with the ' \
+              'following requirements' % (distro_id, indexname)
         for x in index_reqs:
             print '  ', x.strip()
 
