@@ -282,6 +282,17 @@ class SecurityManager(object):
         if username:
             self.logger.info('Roles for user "%s" updated' % username)
 
+    def get_groups(self, username):
+        ses = self.sessionmaker()
+        groupquery = ses.query(SQLGroup).filter_by
+        s = sql.select([users_groups_table.c.groupname],
+                       users_groups_table.c.username==username)
+        groups = set()
+        for row in ses.execute(s):
+            g = groupquery(groupname=row[0]).one()
+            groups.add(g.groupname)
+        return groups
+
     def update_users_groups(self, username, groups):
         username = _u(username)
         groups = [_u(x) for x in groups]
