@@ -119,6 +119,10 @@ class AbstractPyPiApp(object):
                 utils.pop_path(environ)
                 return res(environ, start_response)
 
+            res = getattr(self, 'app_'+endpoint, None)
+            if res is not None:
+                return res(environ, start_response)
+
             attr = getattr(self, 'respond_'+endpoint, None)
             if attr is not None:
                 res = attr(werkzeug.Request(environ), **kwargs)
@@ -231,7 +235,7 @@ def try_to_update(pypi, distro_id, backup_pypis):
 
             for rel, urldict in urls:
                 content = utils.UrlContent(urldict['url'], urldict['filename'])
-                pypi.upload_files(name, content, rel)
+                pypi.upload_files(name, content)
 
             return True
 
@@ -250,6 +254,7 @@ class PyPiInnerApp(AbstractPyPiApp):
     urlmap.add(routing.Rule('/simple', redirect_to='simple/'))
     urlmap.add(routing.Rule('/simple/', endpoint='simple'))
     urlmap.add(RegexRule('/simple/.*', endpoint='simple'))
+    urlmap.add(routing.Rule('/favicon.ico', endpoint='special_static'))
     urlmap.add(routing.Rule('/<distro_id>/', endpoint='redirect_distro'))
     urlmap.add(routing.Rule('/d/<distro_id>/', endpoint='distro'))
     urlmap.add(routing.Rule('/d/<distro_id>/f/<filename>', endpoint='file'))
@@ -262,6 +267,11 @@ class PyPiInnerApp(AbstractPyPiApp):
         self.subapp_simple = SimpleIndexApp(pypi, backup_pypis)
         self.backup_pypis = backup_pypis
 
+    def app_special_static(self, environ, start_response):
+        env = dict(environ)
+        env['PATH_INFO'] = '/static' + env['PATH_INFO']
+        return self.top(env, start_response)
+
     def respond_redirect_distro(self, req, distro_id):
         url = req.url_root
         if not url.endswith('/'):
@@ -524,6 +534,7 @@ class PyPiApp(object):
         # -- no security, no vh, etc
         app = werkzeug.SharedDataMiddleware(
             app, {'/static': ('clue.relmgr', 'static')})
+        innerapp.top = app
 
         return app
 
